@@ -37,6 +37,7 @@ class Parameter(ABC):
     _value: int
     _min_value: int
     _max_value: int
+    _changed: bool = False
 
     def __init__(
         self,
@@ -56,6 +57,7 @@ class Parameter(ABC):
         self._value = _normalize_parameter_value(value)
         self._min_value = _normalize_parameter_value(min_value)
         self._max_value = _normalize_parameter_value(max_value)
+        self._changed = False
 
     def __repr__(self) -> str:
         """Returns serializable string representation."""
@@ -102,6 +104,7 @@ class Parameter(ABC):
         if self.min_value <= value <= self.max_value:
             self._value = value
             self._queue.put_nowait(self.request)
+            self._changed = True
         else:
             raise ValueError(
                 f"parameter value must be between {self.min_value} and {self.max_value}"
@@ -122,6 +125,11 @@ class Parameter(ABC):
         """Return maximum allowed value."""
         return self._max_value
 
+    @property
+    def changed(self) -> bool:
+        """Has parameter been changed recently."""
+        return self._changed
+
     @property
     @abstractmethod
     def request(self) -> Request:
