@@ -1,19 +1,17 @@
 """Contains alarms structure parser."""
+from __future__ import annotations
 
-from typing import Any, Dict, Final, Optional, Tuple
+from typing import Final, Optional, Tuple
+
+from pyplumio.helpers.typing import Records
 
 ALARMS: Final = "alarms"
 
 
 def from_bytes(
-    message: bytearray, offset: int = 0, data: Optional[Dict[str, Any]] = None
-) -> Tuple[Dict, int]:
-    """Parses frame message into usable data.
-
-    Keyword arguments:
-        message -- message bytes
-        offset -- current data offset
-    """
+    message: bytearray, offset: int = 0, data: Optional[Records] = None
+) -> Tuple[Records, int]:
+    """Parse bytes and return message data and offset."""
     if data is None:
         data = {}
 
